@@ -7,14 +7,14 @@ sub setup_test_db {
     my $self = shift;
     return unless $self->dbh;
     my @statements = (
-        qq{
+        q{
             CREATE TABLE books (
                 id         INTEGER PRIMARY KEY AUTOINCREMENT,
                 author_id  INT,
                 name       TEXT
             )
         },
-        qq{
+        q{
             CREATE TABLE authors (
                 id           INT,
                 gender_name  TEXT,
@@ -22,17 +22,31 @@ sub setup_test_db {
                 name         TEXT
             )
         },
-        qq{
+        q{
             CREATE TABLE genders (
                 name  TEXT
             )
         },
-        qq{
+        q{
             CREATE TABLE prefectures (
                 id    INT,
                 name  TEXT PRIMARY KEY
             )
         },
+        q{
+            CREATE TABLE composite (
+                    id   int,
+                    name varchar(255),
+                    primary key (id, name)
+                )
+        },
+        q{
+            CREATE TABLE no_pk (
+                code int,
+                name varchar(255)
+            )
+        },
+
         q{ INSERT INTO books VALUES (1, 1, 'book1') },
     );
     $self->dbh->do($_) for @statements;
